Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1049)

Unified Diff: chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc

Issue 2934513003: Changes in app.window and app.runtime to support lock screen note taking (Closed)
Patch Set: split out browsertests Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
diff --git a/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc b/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
index 501fc6419610e560dd80f92aa8f4edb95dbbe73a..bb2a72fa3c6818ec0c14281dae7f3af6b667178c 100644
--- a/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
+++ b/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
@@ -146,9 +146,12 @@ void ChromeNativeAppWindowViewsAuraAsh::OnBeforeWidgetInit(
views::Widget* widget) {
ChromeNativeAppWindowViewsAura::OnBeforeWidgetInit(create_params, init_params,
widget);
- if (create_params.is_ime_window) {
- // Put ime windows into the ime window container on the primary display.
- int container_id = ash::kShellWindowId_ImeWindowParentContainer;
+ if (create_params.is_ime_window || create_params.show_on_lock_screen) {
+ // Put ime windows and lock screen windows into their respective window
benwells 2017/06/13 10:30:46 Nit: two spaces after respective
tbarzic 2017/06/13 19:17:59 Done.
+ // containers on the primary display.
+ int container_id = create_params.is_ime_window
+ ? ash::kShellWindowId_ImeWindowParentContainer
+ : ash::kShellWindowId_LockActionHandlerContainer;
if (ash_util::IsRunningInMash()) {
init_params->mus_properties
[ui::mojom::WindowManager::kContainerId_InitProperty] =

Powered by Google App Engine
This is Rietveld 408576698